@@ -100,6 +100,8 @@ class EmuConfig:
             return TE0720()
         elif self.cfg.board_name == BoardNames.ZC702:
             return ZC702()
+        elif self.cfg.board_name == BoardNames.ZC706:
+            return ZC706()
         elif self.cfg.board_name == BoardNames.ARTY_200T_CUSTOM_LIDAR:
             return ARTY_200T_CUSTOM_LIDAR()
         else:
